open_slides: Open slides in browser.

View source: R/utils.R

open_slidesR Documentation

Open slides in browser.

Description

Call this function with the session number as argument and the slides of that session will open in your browser (an internet connection is required).

Usage

open_slides(session)

Arguments

session

Session number as a number.

Value

Nothing. Used for its side effects.

Examples

## Not run: 
open_slides(0)

## End(Not run)

stefanocoretta/bayes.handson documentation built on Oct. 3, 2023, 11:03 p.m.