| open_slides | R Documentation |
Call this function with the session number as argument and the slides of that session will open in your browser (an internet connection is required).
open_slides(session)
session |
Session number as a number. |
Nothing. Used for its side effects.
## Not run:
open_slides(0)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.